@@ -11,7 +11,7 @@ import os
 from pkg_resources import iter_entry_points
 
 from .context import Context
-from .operator import main as operator
+from .plugin import main as plugin
 from .recipe import main as recipe
 from .repository import main as repository
 from .config import main as config
@@ -26,30 +26,30 @@ MODULE_PATH = os.path.abspath(os.path.dirname(__file__))
 @click.pass_context
 def main(ctx):
     """ The Queenbee Resource Manager
-    
+
     Making new things::
 
-        queenbee operator new
-        
+        queenbee plugin new
+
 
         queenbee recipe new
-    
-    
+
+
     Packaging things::
 
-        queenbee operator package PATH/TO/OPERATOR
-        
+        queenbee plugin package PATH/TO/PLUGIN
+
 
         queenbee recipe package PATH/TO/RECIPE
 
 
     Checking things are ok::
 
-        queenbee operator lint PATH/TO/OPERATOR
-        
+        queenbee plugin lint PATH/TO/PLUGIN
+
 
         queenbee recipe lint PATH/TO/RECIPE
-   
+
 
     You can use the commands documented below to help you manage queenbee objects
 
@@ -67,7 +67,7 @@ def main(ctx):
 def viz():
     """check queenbee is flying"""
     click.echo("""
-    
+
                                        .' '.            __
   viiiiiiiiiiiiizzzzzzzzz!  . .        .   .           (__\_
                                .         .         . -{{_(|8)
@@ -77,6 +77,6 @@ def viz():
 
 
 main.add_command(config)
-main.add_command(operator)
+main.add_command(plugin)
 main.add_command(recipe)
 main.add_command(repository)
