@@ -1,4 +1,4 @@
-from ...config.auth import PollinationAuth
+from ...config.auth import HeaderAuth
 
 try:
     import click
@@ -8,18 +8,27 @@ except ImportError:
         'click modules not installed. Try `pip install queenbee[cli]` command.'
     )
 
+
 @click.group('auth')
 def auth():
     """manage queenbee configuration auth"""
     pass
 
+
 @auth.group('add')
 def add():
     """add auth domains and methods to your queenbee config"""
     pass
 
-@add.command('pollination')
+@add.command('api_token')
 @click.argument('api_token')
+@click.option(
+    '-n',
+    '--header-name',
+    help='API token header name',
+    show_default=True,
+    default='x-pollination-token'
+)
 @click.option(
     '-d',
     '--domain',
@@ -27,16 +36,16 @@ def add():
     show_default=True,
     default='api.pollination.cloud'
 )
-def add_pollination(api_token, domain):
-    """add a pollination auth domain"""
+def add_api_token(api_token, header_name, domain):
+    """add an API token auth config"""
     ctx = click.get_current_context()
-    
-    auth_conf = PollinationAuth(
-        domain=domain,
-        api_token=api_token,
-    )
 
+    auth_conf = HeaderAuth(
+        domain=domain,
+        header_name=header_name,
+        access_token=api_token,
+    )
     ctx.obj.config.add_auth(auth=auth_conf)
 
     ctx.obj.write_config()
-
+    
