@@ -1,4 +1,5 @@
 import os
+import shutil
 
 from pydantic import ValidationError
 
@@ -33,12 +34,14 @@ def install(path):
         raise error
     os.chdir(path)
 
+    if os.path.exists('.dependencies'):
+        shutil.rmtree('.dependencies')
+
     recipe.lock_dependencies(config=ctx.obj.config)
-    
+
     recipe.write_dependency_file('.')
 
     recipe.write_dependencies(
         folder_path='.',
         config=ctx.obj.config,
     )
-
