@@ -30,37 +30,37 @@ def new(name, path):
         \b
         metadata:
             name: <input-name>
-            version: 0.1.0
+            tag: 0.1.0
         dependencies:
-        - type: operator
+        - kind: plugin
         name: whalesay
-        version: 0.1.0
+        tag: 0.1.0
         source: https://pollination.github.io/shed # Replace with name of repo
         flow:
         - name: main
         inputs:
-            parameters:
             - name: thing-to-say
+            type: DAGStringInput
             default: hi
             description: What the whale will say
         tasks:
         - name: say-something
             template: whalesay/say-hi
             arguments:
-            parameters:
             - name: message
+                type: TaskArgument
                 from:
-                type: inputs
-                variable: thing-to-say
-            outputs:
-            parameters:
+                  type: InputReference
+                  variable: thing-to-say
+            returns:
             - name: whale-said
+                type: TaskReturn
 
         outputs:
-            parameters:
             - name: what-the-whale-said
+            type: DAGStringOutput
             from:
-                type: tasks
+                type: TaskReference
                 name: say-something
                 variable: whale-said
 
@@ -75,7 +75,8 @@ def new(name, path):
     folder_path = os.path.abspath(folder_path)
 
     if os.path.exists(folder_path):
-        raise click.ClickException(f'Cannot create new recipe at path {folder_path} because there is already something there')
+        raise click.ClickException(
+            f'Cannot create new recipe at path {folder_path} because there is already something there')
 
     path = os.path.join(MODULE_PATH, '../assets/new-recipe.yaml')
     input_dict = parse_file(path)
