@@ -9,8 +9,6 @@ except ImportError:
         'click modules not installed. Try `pip install queenbee[cli]` command.'
     )
 
-MODULE_PATH = os.path.abspath(os.path.dirname(__file__))
-
 
 @click.command('init')
 @click.argument('path', type=click.Path(exists=False))
@@ -22,8 +20,8 @@ def init(path):
 
     path = os.path.abspath(path)
 
-    os.makedirs(os.path.join(path, 'workflows'))
-    os.makedirs(os.path.join(path, 'recipes'))
+    os.makedirs(os.path.join(path, 'plugins'), exist_ok=True)
+    os.makedirs(os.path.join(path, 'recipes'), exist_ok=True)
 
     index = RepositoryIndex.from_folder(path)
 
