@@ -9,8 +9,6 @@ except ImportError:
         'click modules not installed. Try `pip install queenbee[cli]` command.'
     )
 
-MODULE_PATH = os.path.abspath(os.path.dirname(__file__))
-
 
 @click.command('serve')
 @click.argument('path', type=click.Path(exists=True))
@@ -27,5 +25,6 @@ def serve(port, address, path):
 
     http = HTTPServer((address, 8000), SimpleHTTPRequestHandler)
 
-    print(f'Serving HTTP on {address} port {port} (http://{address}:{port}/) ...')
+    print(
+        f'Serving HTTP on {address} port {port} (http://{address}:{port}/) ...')
     http.serve_forever()
