@@ -1,28 +1,28 @@
 """Queenbee dependency class."""
 import os
+from typing import Dict
 from enum import Enum
-from io import BytesIO
-from urllib import request
-from typing import Tuple
-
-from pydantic import Field
+from pydantic import Field, constr
 
 from ..base.basemodel import BaseModel
 from ..base.request import make_request, urljoin
 
-class DependencyType(str, Enum):
 
+class DependencyKind(str, Enum):
+    """Dependency kind."""
     recipe = 'recipe'
 
-    operator = 'operator'
+    plugin = 'plugin'
 
 
 class Dependency(BaseModel):
-    """Configuration to fetch a Recipe or Operator that another Recipe depends on."""
+    """Configuration to fetch a Recipe or Plugin that another Recipe depends on."""
+    type: constr(regex='^Dependency$') = 'Dependency'
 
-    type: DependencyType = Field(
+    kind: DependencyKind = Field(
         ...,
-        description='The type of dependency'
+        description='The kind of dependency. It can be a recipe or an '
+        'plugin.'
     )
 
     name: str = Field(
@@ -58,6 +58,14 @@ class Dependency(BaseModel):
         ]
     )
 
+    @property
+    def dependency_kind(self):
+        """Return a clean version of dependency kind.
+
+        The value is either `recipe` or `plugin`.
+        """
+        return self.kind.split('_')[0]
+
     @property
     def is_locked(self) -> bool:
         """Indicates whether the dependency is locked to a specific digest.
@@ -78,7 +86,7 @@ class Dependency(BaseModel):
             return self.alias
         return self.name
 
-    def _fetch_index(self, auth_header: str = ''):
+    def _fetch_index(self, auth_header: Dict[str, str] = {}):
         """Fetch the source repository index object.
 
         Returns:
@@ -86,12 +94,12 @@ class Dependency(BaseModel):
         """
         from ..repository.index import RepositoryIndex
 
-        if self.source.startswith('file:'):
-            rel_path = self.source.split('file:')[1]
+        if self.source.startswith('file:///'):
+            rel_path = self.source.split('file:///')[1]
 
             abs_path = os.path.join(os.getcwd(), rel_path, 'index.json')
 
-            url = f'file:{abs_path}'
+            url = f'file:///{abs_path}'
         else:
             url = urljoin(self.source, 'index.json')
 
@@ -100,7 +108,7 @@ class Dependency(BaseModel):
         raw_bytes = res.read()
         return RepositoryIndex.parse_raw(raw_bytes)
 
-    def fetch(self, verify_digest: bool = True, auth_header: str = '') -> Tuple[bytes, str, str, str]:
+    def fetch(self, verify_digest: bool = True, auth_header: Dict[str, str] = {}) -> 'PackageVersion':
         """Fetch the dependency from its source
 
         Keyword Arguments:
@@ -121,7 +129,7 @@ class Dependency(BaseModel):
 
         if self.digest is None:
             package_meta = index.package_by_tag(
-                package_type=self.type,
+                kind=self.dependency_kind,
                 package_name=self.name,
                 package_tag=self.tag
             )
@@ -130,7 +138,7 @@ class Dependency(BaseModel):
         else:
             try:
                 package_meta = index.package_by_digest(
-                    package_type=self.type,
+                    kind=self.dependency_kind,
                     package_name=self.name,
                     package_digest=self.digest
                 )
@@ -138,10 +146,10 @@ class Dependency(BaseModel):
                 # If hash does not exist then try to download
                 # by tag. This is in the case where some package
                 # owner overwrote the tag of the dependency
-                if str(error) == f'No {self.type} package with name {self.name} ' \
-                        'and digest {self.digest} exists in this index':
+                if str(error) == f'No {self.dependency_kind} package with name ' \
+                    f'{self.name} and digest {self.digest} exists in this index':
                     package_meta = index.package_by_tag(
-                        package_type=self.type,
+                        kind=self.dependency_kind,
                         package_name=self.name,
                         package_tag=self.tag
                     )
