@@ -1,6 +1,6 @@
 """Queenbee recipe class.
 
-Recipe is a collection of operators and inter-related tasks that describes an end to
+Recipe is a collection of plugins and inter-related tasks that describes an end to
 end steps for the recipe.
 """
 import os
@@ -9,43 +9,46 @@ import json
 from typing import List, Union, Dict
 
 import yaml
-from pydantic import Field, validator, root_validator
+from pydantic import Field, validator, root_validator, constr
 
 from ..base.basemodel import BaseModel
-from ..config import Config
-from ..operator import Operator
-from ..operator.function import Function
-from ..operator.operator import Config as OperatorConfig
+from ..base.metadata import MetaData
 
-from .dag import DAG, DAGInputs
-from .metadata import MetaData
-from .dependency import Dependency, DependencyType
+from ..config import Config
+from ..plugin import Plugin
+from ..plugin.function import Function
+from ..plugin.plugin import PluginConfig
+
+from .dag import DAG, DAGInputs, DAGOutputs
+from .dependency import Dependency, DependencyKind
 
 
 class TemplateFunction(Function):
     """Function template."""
+    type: constr(regex='^TemplateFunction$') = 'TemplateFunction'
 
-    config: OperatorConfig = Field(
+    config: PluginConfig = Field(
         ...,
-        description='The operator config to use for this function'
+        description='The plugin config to use for this function'
     )
 
     @classmethod
-    def from_operator(cls, operator: Operator) -> list:
-        """Generate a list of template functions from an operator
+    def from_plugin(cls, plugin: Plugin) -> list:
+        """Generate a list of template functions from a plugin
 
         Arguments:
-            operator {Operator} -- An Operator
+            plugin {Plugin} -- A plugin
 
         Returns:
             list -- A list of template functions
         """
         functions = []
 
-        for function in operator.functions:
+        for function in plugin.functions:
             input_dict = function.to_dict()
-            input_dict['name'] = f'{operator.__hash__}/{function.name}'
-            input_dict['config'] = operator.config.to_dict()
+            input_dict['type'] = 'TemplateFunction'
+            input_dict['name'] = f'{plugin.__hash__}/{function.name}'
+            input_dict['config'] = plugin.config.to_dict()
             functions.append(cls.parse_obj(input_dict))
 
         return functions
@@ -53,6 +56,9 @@ class TemplateFunction(Function):
 
 class Recipe(BaseModel):
     """A Queenbee Recipe"""
+    api_version: constr(regex='^v1beta1$') = Field('v1beta1', readOnly=True)
+
+    type: constr(regex='^Recipe$') = 'Recipe'
 
     metadata: MetaData = Field(
         None,
@@ -61,7 +67,7 @@ class Recipe(BaseModel):
 
     dependencies: List[Dependency] = Field(
         None,
-        description='A list of operators and other recipes this recipe depends on.'
+        description='A list of plugins and other recipes this recipe depends on.'
     )
 
     flow: List[DAG] = Field(
@@ -79,7 +85,7 @@ class Recipe(BaseModel):
 
                 .
                 ├── .dependencies
-                │   ├── operators
+                │   ├── plugins
                 │   │   └── <sha-256>.yaml
                 │   └── recipes
                 │       └── <sha-256>.yaml
@@ -87,7 +93,7 @@ class Recipe(BaseModel):
                 |   ├── sub-dag.yaml
                 │   └── main.yaml
                 ├── dependencies.yaml
-                └── recipe.yaml
+                └── package.yaml
 
         Arguments:
             folder_path {str} -- Path to the folder
@@ -96,7 +102,7 @@ class Recipe(BaseModel):
             Recipe -- A Recipe
         """
         folder_path = os.path.realpath(folder_path)
-        meta_path = os.path.join(folder_path, 'recipe.yaml')
+        meta_path = os.path.join(folder_path, 'package.yaml')
         dependencies_path = os.path.join(folder_path, 'dependencies.yaml')
         flow_path = os.path.join(folder_path, 'flow')
 
@@ -160,8 +166,8 @@ class Recipe(BaseModel):
 
         for dag in v:
             for template in dag.templates:
-                operator = template.split('/')[0]
-                assert operator in op_names, \
+                plugin = template.split('/')[0]
+                assert plugin in op_names, \
                     ValueError(
                         f'Cannot use template {template} from DAG {dag.name} because no'
                         f' dependency or other DAG matching that name was found.'
@@ -174,14 +180,23 @@ class Recipe(BaseModel):
         return self.dag_by_name(flow=self.flow, name='main')
 
     @property
-    def inputs(self) -> DAGInputs:
+    def inputs(self) -> List[DAGInputs]:
         """Get the Recipe's inputs
 
         Returns:
-            DAGInputs -- The inputs of the entrypoint DAG
+            List[DAGInputs] -- The inputs of the entrypoint DAG
         """
         return self.root_dag.inputs
 
+    @property
+    def outputs(self) -> List[DAGOutputs]:
+        """Get the Recipe's outputs
+
+        Returns:
+            List[DAGOutputs] -- The outputs of the entrypoint DAG
+        """
+        return self.root_dag.outputs
+
     @property
     def is_locked(self) -> bool:
         """Indicates whether the Recipe dependencies are all locked
@@ -229,14 +244,16 @@ class Recipe(BaseModel):
         res = next(filter(lambda x: x.name == name, flow), None)
 
         if res is None:
-            raise ValueError(f'No DAG with reference name {name} found in flow')
+            raise ValueError(
+                f'No DAG with reference name {name} found in flow')
 
         return res
 
     def lock_dependencies(self, config: Config = Config()):
         """Lock the dependencies by fetching them and storing their digest"""
         for dependency in self.dependencies:
-            auth_header = config.get_auth_header(registry_url=dependency.source)
+            auth_header = config.get_auth_header(
+                repository_url=dependency.source)
             dependency.fetch(auth_header=auth_header)
 
     def write_dependency_file(self, folder_path: str):
@@ -246,7 +263,7 @@ class Recipe(BaseModel):
             folder_path {str} -- The path to the recipe folder
         """
 
-        self_dict = json.loads(self.json(by_alias=True, exclude_unset=True))
+        self_dict = json.loads(self.json(by_alias=True, exclude_unset=False))
 
         with open(os.path.join(folder_path, 'dependencies.yaml'), 'w') as f:
             f.write(
@@ -256,7 +273,7 @@ class Recipe(BaseModel):
                 )
             )
 
-    def to_folder(self, folder_path: str, readme_string: str = None, license_string: str = None):
+    def to_folder(self, folder_path: str, readme_string: str = None):
         """Write a Recipe to a folder
 
         Note:
@@ -265,40 +282,39 @@ class Recipe(BaseModel):
 
                 .
                 ├── .dependencies
-                │   ├── operator
-                │   │   └── operator-dep-name
+                │   ├── plugin
+                │   │   └── plugin-dep-name
                 │   │       ├── functions
                 │   │       │   ├── func-1.yaml
                 │   │       │   ├── ...
                 │   │       │   └── func-n.yaml
                 │   │       ├── config.yaml
-                │   │       └── operator.yaml
+                │   │       └── package.yaml
                 │   └── recipe
                 │       └── recipe-dep-name
                 │           ├── .dependencies
-                │           │   ├── operator
+                │           │   ├── plugin
                 │           │   └── recipe
                 │           ├── flow
                 │           │   └── main.yaml
                 │           ├── dependencies.yaml
-                │           └── recipe.yaml
+                │           └── package.yaml
                 ├── flow
                 │   └── main.yaml
                 ├── dependencies.yaml
-                └── recipe.yaml
+                └── package.yaml
 
         Arguments:
             folder_path {str} -- The path to the Recipe folder
 
         Keyword Arguments:
             readme_string {str} -- The README file string (default: {None})
-            license_string {str} -- The LICENSE file string (default: {None})
         """
 
-        os.makedirs(os.path.join(folder_path, 'flow'))
+        os.makedirs(os.path.join(folder_path, 'flow'), exist_ok=True)
 
         self.metadata.to_yaml(
-            os.path.join(folder_path, 'recipe.yaml'), exclude_unset=True
+            os.path.join(folder_path, 'package.yaml'), exclude_unset=False
         )
 
         self.write_dependency_file(folder_path)
@@ -306,16 +322,15 @@ class Recipe(BaseModel):
         for dag in self.flow:
             dag.to_yaml(
                 os.path.join(folder_path, 'flow', f'{dag.name}.yaml'),
-                exclude_unset=True
+                exclude_unset=False
             )
 
         if readme_string is not None:
             with open(os.path.join(folder_path, 'README.md'), 'w') as f:
                 f.write(readme_string)
 
-        if license_string is not None:
-            with open(os.path.join(folder_path, 'LICENSE'), 'w') as f:
-                f.write(license_string)
+        with open(os.path.join(folder_path, 'LICENSE'), 'w') as f:
+            f.write('To see the license for this package refer to package.yaml')
 
     def write_dependencies(self, folder_path: str, config: Config = Config()):
         """Fetch dependencies manifests and write them to the `.dependencies` folder
@@ -326,37 +341,36 @@ class Recipe(BaseModel):
             config {Config} -- A queenbee config object (default: {Config()})
         """
         dependencies_folder = os.path.join(folder_path, '.dependencies')
-        operator_folder = os.path.join(dependencies_folder, 'operator')
+        plugin_folder = os.path.join(dependencies_folder, 'plugin')
         recipes_folder = os.path.join(dependencies_folder, 'recipe')
 
         if not os.path.isdir(dependencies_folder):
-            os.mkdir(dependencies_folder)
+            os.makedirs(dependencies_folder, exist_ok=True)
 
-        if not os.path.isdir(operator_folder):
-            os.mkdir(operator_folder)
+        if not os.path.isdir(plugin_folder):
+            os.makedirs(plugin_folder, exist_ok=True)
 
         if not os.path.isdir(recipes_folder):
-            os.mkdir(recipes_folder)
+            os.makedirs(recipes_folder, exist_ok=True)
 
         for dependency in self.dependencies:
-            if dependency.type == DependencyType.operator:
-                auth_header = config.get_auth_header(registry_url=dependency.source)
-                raw_dep, digest, readme_string, license_string = dependency.fetch(auth_header=auth_header)
-                dep = Operator.parse_raw(raw_dep)
+            auth_header = config.get_auth_header(
+                repository_url=dependency.source)
+            package_version = dependency.fetch(auth_header=auth_header)
+            dep = package_version.manifest
 
-            elif dependency.type == DependencyType.recipe:
-                auth_header = config.get_auth_header(registry_url=dependency.source)
-                raw_dep, digest, readme_string, license_string = dependency.fetch(auth_header=auth_header)
-                dep = self.__class__.parse_raw(raw_dep)
+            if dependency.kind == DependencyKind.recipe:
                 dep.write_dependencies(
-                    folder_path=folder_path,
+                    folder_path=os.path.join(
+                        recipes_folder, dependency.ref_name),
                     config=config,
                 )
 
             dep.to_folder(
-                folder_path=os.path.join(folder_path, '.dependencies', dependency.type, dependency.ref_name),
-                readme_string=readme_string,
-                license_string=license_string,
+                folder_path=os.path.join(
+                    folder_path, '.dependencies',
+                    dependency.dependency_kind, dependency.ref_name),
+                readme_string=package_version.readme
             )
 
 
@@ -366,6 +380,7 @@ class BakedRecipe(Recipe):
     A Baked Recipe contains all the templates referred to in the DAG within a templates
     list.
     """
+    type: constr(regex='^BakedRecipe$') = 'BakedRecipe'
 
     digest: str
 
@@ -403,24 +418,25 @@ class BakedRecipe(Recipe):
         templates = []
 
         for dependency in recipe.dependencies:
-            auth_header = config.get_auth_header(registry_url=dependency.source)
-            dep_bytes, dep_hash, _, _ = dependency.fetch(auth_header=auth_header)
+            auth_header = config.get_auth_header(
+                repository_url=dependency.source)
+            package_version = dependency.fetch(auth_header=auth_header)
+            dep = package_version.manifest
 
-            if dependency.type == 'recipe':
-                dep = Recipe.parse_raw(dep_bytes)
-                sub_recipe = cls.from_recipe(dep)
+            if dependency.kind == DependencyKind.recipe:
+                sub_recipe = cls.from_recipe(recipe=dep, config=config)
 
                 templates.extend(sub_recipe.templates)
                 templates.extend(sub_recipe.flow)
                 digest_dict[dependency.ref_name] = sub_recipe.digest
 
-            elif dependency.type == 'operator':
-                dep = Operator.parse_raw(dep_bytes)
-                templates.extend(TemplateFunction.from_operator(dep))
+            elif dependency.kind == DependencyKind.plugin:
+                templates.extend(TemplateFunction.from_plugin(dep))
                 digest_dict[dependency.ref_name] = dep.__hash__
 
             else:
-                raise ValueError(f'Dependency of type {dependency.type} not recognized')
+                raise ValueError(
+                    f'Dependency of type {dependency.kind} not recognized')
 
         flow = cls.replace_template_refs(
             dependencies=recipe.dependencies,
@@ -429,9 +445,11 @@ class BakedRecipe(Recipe):
         )
 
         input_dict = recipe.to_dict()
+        input_dict['type'] = 'BakedRecipe'
         input_dict['digest'] = digest
         input_dict['flow'] = [dag.to_dict() for dag in flow]
-        input_dict['templates'] = [template.to_dict() for template in templates]
+        input_dict['templates'] = [template.to_dict()
+                                   for template in templates]
 
         return cls.parse_obj(input_dict)
 
@@ -445,7 +463,7 @@ class BakedRecipe(Recipe):
 
                 .
                 ├── .dependencies
-                │   ├── operators
+                │   ├── plugins
                 │   │   └── <sha-256>.yaml
                 │   └── recipes
                 │       └── <sha-256>.yaml
@@ -453,7 +471,7 @@ class BakedRecipe(Recipe):
                 |   ├── sub-dag.yaml
                 │   └── main.yaml
                 ├── dependencies.yaml
-                └── recipe.yaml
+                └── package.yaml
 
 
         Arguments:
@@ -488,16 +506,16 @@ class BakedRecipe(Recipe):
 
         templates = []
 
-        operators_folder = os.path.join(dependencies_folder, 'operator')
-        if os.path.isdir(operators_folder):
-            for operator_dep_name in os.listdir(operators_folder):
-                operator = Operator.from_folder(
+        plugins_folder = os.path.join(dependencies_folder, 'plugin')
+        if os.path.isdir(plugins_folder):
+            for plugin_dep_name in os.listdir(plugins_folder):
+                plugin = Plugin.from_folder(
                     folder_path=os.path.join(
-                        dependencies_folder, 'operator', operator_dep_name
+                        dependencies_folder, 'plugin', plugin_dep_name
                     )
                 )
-                templates.extend(TemplateFunction.from_operator(operator))
-                digest_dict[operator_dep_name] = operator.__hash__
+                templates.extend(TemplateFunction.from_plugin(plugin))
+                digest_dict[plugin_dep_name] = plugin.__hash__
 
         recipes_folder = os.path.join(dependencies_folder, 'recipe')
         if os.path.isdir(recipes_folder):
@@ -506,7 +524,8 @@ class BakedRecipe(Recipe):
                     folder_path=os.path.join(
                         dependencies_folder, 'recipe', recipe_dep_name
                     ),
-                    refresh_deps=refresh_deps
+                    refresh_deps=refresh_deps,
+                    config=config,
                 )
 
                 templates.extend(sub_baked_recipe.templates)
@@ -520,9 +539,11 @@ class BakedRecipe(Recipe):
         )
 
         input_dict = recipe.to_dict()
+        input_dict['type'] = 'BakedRecipe'
         input_dict['digest'] = digest
         input_dict['flow'] = [dag.to_dict() for dag in flow]
-        input_dict['templates'] = [template.to_dict() for template in templates]
+        input_dict['templates'] = [template.to_dict()
+                                   for template in templates]
 
         return cls.parse_obj(input_dict)
 
@@ -549,7 +570,8 @@ class BakedRecipe(Recipe):
         dag_names = [dag.name for dag in dags]
 
         if dependencies is None:
-            raise ValueError('Cannot resolve template refs without dependencies')
+            raise ValueError(
+                'Cannot resolve template refs without dependencies')
 
         for dag in dags:
             # Replace name of DAG to "{digest}/{dag.name}"
@@ -566,33 +588,36 @@ class BakedRecipe(Recipe):
                     task.template = f'{dep_hash}/{template_dep_list[0]}'
                     continue
 
-                dep = cls.dependency_by_name(dependencies, template_dep_list[0])
+                dep = cls.dependency_by_name(
+                    dependencies, template_dep_list[0])
 
                 try:
                     dep_hash = digest_dict[dep.ref_name]
                 except KeyError:
                     raise ValueError(
                         f'Unresolvable dependency name {dep.ref_name}. Did you forget '
-                        f' to package or link {dep.ref_name}?'
+                        f'to package or link {dep.ref_name}? '
+                        'See `queenbee recipe link --help` for more information.'
                     )
 
                 # Template name is another Recipe
-                if dep.type == DependencyType.recipe:
+                if dep.kind == DependencyKind.recipe:
                     assert len(template_dep_list) == 1, \
                         ValueError(
                             f'Unresolvable Recipe template dependency {task.template}'
-                        )
+                    )
                     template_dep = f'{dep_hash}/main'
 
-                # Template name is an Operator Function
-                elif dep.type == DependencyType.operator:
+                # Template name is a plugin Function
+                elif dep.kind == DependencyKind.plugin:
                     assert len(template_dep_list) == 2, \
                         ValueError(
-                            f'Unresolvable Operator function template dependency'
+                            f'Unresolvable Plugin function template dependency'
                             f' {task.template}'
-                        )
+                    )
                     template_dep = f'{dep_hash}/{template_dep_list[1]}'
-
+                else:
+                    raise ValueError(f'Invalid dependency type: {dep.kind}')
                 task.template = template_dep
 
         return dags
@@ -654,3 +679,48 @@ class BakedRecipe(Recipe):
             raise ValueError(f'No dependency with reference name {name} found')
 
         return res
+
+
+class RecipeInterface(BaseModel):
+    """An interface object for creating a Recipe.
+
+    Recipe information only includes metadata, source, inputs and outputs of a Recipe.
+    This object is useful for creating user interface for Recipes.
+    """
+    api_version: constr(regex='^v1beta1$') = Field('v1beta1', readOnly=True)
+
+    type: constr(regex='^RecipeInterface$') = 'RecipeInterface'
+
+    metadata: MetaData = Field(
+        ...,
+        description='Recipe metadata information.'
+    )
+
+    source: str = Field(
+        None,
+        description='A URL to the source this recipe from a registry.'
+    )
+
+    inputs: List[DAGInputs] = Field(
+        None,
+        description='A list of recipe inputs.'
+    )
+
+    outputs: List[DAGOutputs] = Field(
+        None,
+        description='A list of recipe outputs.'
+    )
+
+    @validator('inputs', 'outputs')
+    def create_empty_list(cls, v):
+        return [] if not v else v
+
+    @classmethod
+    def from_recipe(cls, recipe: Union[Recipe, BakedRecipe], source: str = None):
+        """Create a Recipe info from a recipe."""
+        return cls(
+            metadata=recipe.metadata,
+            source=source,
+            inputs=recipe.inputs,
+            outputs=recipe.outputs
+        )
