@@ -15,21 +15,18 @@ class BaseFolderTest(BaseTestClass):
 
         inputs = []
 
-        print(folders)
-        print([i.metadata.name for i in valid_instances])
-
-
         for folder in folders:
             folder_name = os.path.basename(folder)
-            matching_instances = [instance for instance in valid_instances if instance.metadata.name == folder_name]
+            matching_instances = [
+                instance for instance in valid_instances if instance.metadata.name == folder_name]
 
             if len(matching_instances) == 1:
                 inputs.append((folder, matching_instances[0]))
 
-
         if "folder" in metafunc.fixturenames:
-            metafunc.parametrize("folder,instance", inputs, ids=[os.path.basename(input_tuple[0]) for input_tuple in inputs])
-        
+            metafunc.parametrize("folder,instance", inputs, ids=[
+                                 os.path.basename(input_tuple[0]) for input_tuple in inputs])
+
     def class_folders(self):
         return self.fixture_folders('folders')
 
