@@ -3,24 +3,27 @@ from tests.base.io_test import BaseIOTest
 from tests.base.value_error import BaseValueErrorTest
 from tests.base.folder_test import BaseFolderTest
 
-from queenbee.operator import Operator
+from queenbee.plugin import Plugin
+
+ASSET_FOLDER = 'tests/assets/plugins'
 
-ASSET_FOLDER = 'tests/assets/operators'
 
 class TestIO(BaseIOTest):
 
-    klass = Operator
+    klass = Plugin
 
     asset_folder = ASSET_FOLDER
 
+
 class TestValueError(BaseValueErrorTest):
 
-    klass = Operator
+    klass = Plugin
 
     asset_folder = ASSET_FOLDER
 
+
 class TestFolder(BaseFolderTest):
 
-    klass = Operator
+    klass = Plugin
 
     asset_folder = ASSET_FOLDER
